==> haskell-cmark-gfm-0.2.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-EuPpBqK6gQTHe9ju1zHb7h
key:                  cmark-gfm-0.2.6-EuPpBqK6gQTHe9ju1zHb7h
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  bba9b3288a44f59b914921935dffdf51
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-EuPpBqK6gQTHe9ju1zHb7h
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.6-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-IfnRttorgOPEZnRNzTZiXt
key:                  cmark-gfm-0.2.6-IfnRttorgOPEZnRNzTZiXt
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  22497b1fdeaf1a07507e8ecd0fc29fef
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-IfnRttorgOPEZnRNzTZiXt
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
